summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-18 18:12:30 -0600
committerTimothy Pearson <[email protected]>2011-12-18 18:12:30 -0600
commit11191ef0b9908604d1d7aaca382b011ef22c454c (patch)
treed38f0ccd8bfcc9756f5cfc42fb2ad1dad351e6aa /lib/kofficecore
parentc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (diff)
downloadkoffice-11191ef0b9908604d1d7aaca382b011ef22c454c.tar.gz
koffice-11191ef0b9908604d1d7aaca382b011ef22c454c.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'lib/kofficecore')
-rw-r--r--lib/kofficecore/KoChild.cpp6
-rw-r--r--lib/kofficecore/KoDocument.cpp12
-rw-r--r--lib/kofficecore/KoDocumentInfo.cpp6
-rw-r--r--lib/kofficecore/KoDocumentInfoDlg.cpp2
-rw-r--r--lib/kofficecore/KoFilter.cpp2
-rw-r--r--lib/kofficecore/KoFilter.h8
-rw-r--r--lib/kofficecore/KoFilterChain.cpp12
-rw-r--r--lib/kofficecore/KoFilterChain.h4
-rw-r--r--lib/kofficecore/KoFilterManager.cpp6
-rw-r--r--lib/kofficecore/KoFilterManager.h4
-rw-r--r--lib/kofficecore/KoGenStyles.cpp2
-rw-r--r--lib/kofficecore/KoGlobal.cpp2
-rw-r--r--lib/kofficecore/KoMainWindow.cpp4
-rw-r--r--lib/kofficecore/KoPageLayout.cpp6
-rw-r--r--lib/kofficecore/KoPictureEps.cpp2
-rw-r--r--lib/kofficecore/KoPictureKey.cpp2
-rw-r--r--lib/kofficecore/KoQueryTrader.cpp4
-rw-r--r--lib/kofficecore/KoSpeaker.cpp2
-rw-r--r--lib/kofficecore/KoUnit.cpp34
-rw-r--r--lib/kofficecore/KoView.cpp4
-rw-r--r--lib/kofficecore/kkbdaccessextensions.cpp12
-rw-r--r--lib/kofficecore/koDetailsPaneBase.ui8
-rw-r--r--lib/kofficecore/koDocumentInfoAboutWidget.ui14
-rw-r--r--lib/kofficecore/koDocumentInfoAuthorWidget.ui4
-rw-r--r--lib/kofficecore/koDocumentInfoUserMetadataWidget.ui4
25 files changed, 83 insertions, 83 deletions
diff --git a/lib/kofficecore/KoChild.cpp b/lib/kofficecore/KoChild.cpp
index 41dfee8f..e7752347 100644
--- a/lib/kofficecore/KoChild.cpp
+++ b/lib/kofficecore/KoChild.cpp
@@ -123,9 +123,9 @@ void KoChild::setClipRegion( TQPainter &painter, bool combine )
{
painter.setClipping( true );
if ( combine && !painter.clipRegion().isEmpty() )
- painter.setClipRegion( region( painter.tqworldMatrix() ).intersect( painter.clipRegion() ) );
+ painter.setClipRegion( region( painter.worldMatrix() ).intersect( painter.clipRegion() ) );
else
- painter.setClipRegion( region( painter.tqworldMatrix() ) );
+ painter.setClipRegion( region( painter.worldMatrix() ) );
}
void KoChild::setScaling( double x, double y )
@@ -218,7 +218,7 @@ void KoChild::transform( TQPainter &painter )
{
setClipRegion( painter, true );
- TQWMatrix m = painter.tqworldMatrix();
+ TQWMatrix m = painter.worldMatrix();
m = d->m_matrix * m;
m.scale( d->m_scaleX, d->m_scaleY );
painter.setWorldMatrix( m );
diff --git a/lib/kofficecore/KoDocument.cpp b/lib/kofficecore/KoDocument.cpp
index ba3c9d54..ddfce183 100644
--- a/lib/kofficecore/KoDocument.cpp
+++ b/lib/kofficecore/KoDocument.cpp
@@ -401,7 +401,7 @@ bool KoDocument::saveFile()
backup = url();
else
backup = d->m_backupPath +"/"+url().fileName();
- backup.setPath( backup.path() + TQString::tqfromLatin1("~") );
+ backup.setPath( backup.path() + TQString::fromLatin1("~") );
KFileItem item( entry, url() );
Q_ASSERT( item.name() == url().fileName() );
KIO::NetAccess::file_copy( url(), backup, item.permissions(), true /*overwrite*/, false /*resume*/, shells().current() );
@@ -418,7 +418,7 @@ bool KoDocument::saveFile()
if ( !d->filterManager )
d->filterManager = new KoFilterManager( this );
- KoFilter::ConversiontqStatus status = d->filterManager->exp0rt( m_file, outputMimeType );
+ KoFilter::ConversionStatus status = d->filterManager->exp0rt( m_file, outputMimeType );
ret = status == KoFilter::OK;
suppressErrorDialog = (status == KoFilter::UserCancelled || status == KoFilter::BadConversionGraph );
} else {
@@ -1274,7 +1274,7 @@ TQString KoDocument::autoSaveFile( const TQString & path ) const
// Never saved? Use a temp file in $HOME then
// Yes, two open unnamed docs will overwrite each other's autosave file,
// but hmm, we can only do something if that's in the same process anyway...
- TQString ret = TQDir::homeDirPath() + "/." + TQString::tqfromLatin1(instance()->instanceName()) + ".autosave" + extension;
+ TQString ret = TQDir::homeDirPath() + "/." + TQString::fromLatin1(instance()->instanceName()) + ".autosave" + extension;
return ret;
}
else
@@ -1456,7 +1456,7 @@ bool KoDocument::openFile()
if ( !isNativeFormat( typeName.latin1() ) ) {
if ( !d->filterManager )
d->filterManager = new KoFilterManager( this );
- KoFilter::ConversiontqStatus status;
+ KoFilter::ConversionStatus status;
importedFile = d->filterManager->import( m_file, status );
if ( status != KoFilter::OK )
{
@@ -2082,7 +2082,7 @@ void KoDocument::setTitleModified()
// Get caption from document info (title(), in about page)
if ( documentInfo() )
{
- KoDocumentInfoPage * page = documentInfo()->page( TQString::tqfromLatin1("about") );
+ KoDocumentInfoPage * page = documentInfo()->page( TQString::fromLatin1("about") );
if (page)
caption = static_cast<KoDocumentInfoAbout *>(page)->title();
}
@@ -2233,7 +2233,7 @@ KService::Ptr KoDocument::readNativeService( KInstance *instance )
// Try by path first, so that we find the global one (which has the native mimetype)
// even if the user created a kword.desktop in ~/.kde/share/applnk or any subdir of it.
// If he created it under ~/.kde/share/applnk/Office/ then no problem anyway.
- service = KService::serviceByDesktopPath( TQString::tqfromLatin1("Office/%1.desktop").tqarg(instname) );
+ service = KService::serviceByDesktopPath( TQString::fromLatin1("Office/%1.desktop").tqarg(instname) );
}
if ( !service )
service = KService::serviceByDesktopName( instname );
diff --git a/lib/kofficecore/KoDocumentInfo.cpp b/lib/kofficecore/KoDocumentInfo.cpp
index cd4ecbaf..0b54ebbb 100644
--- a/lib/kofficecore/KoDocumentInfo.cpp
+++ b/lib/kofficecore/KoDocumentInfo.cpp
@@ -629,7 +629,7 @@ KoDocumentInfoAbout::KoDocumentInfoAbout( KoDocumentInfo* info )
m_docInfo = info;
m_editingCycles = 0;
m_initialCreator = m_docInfo->creator();
- m_creationDate = TQDateTime::tqcurrentDateTime();
+ m_creationDate = TQDateTime::currentDateTime();
}
void KoDocumentInfoAbout::saveParameters()
@@ -637,7 +637,7 @@ void KoDocumentInfoAbout::saveParameters()
KoDocument* doc = dynamic_cast< KoDocument* >( m_docInfo->parent() );
if ( m_firstSave && doc && !doc->isAutosaving() )
m_editingCycles++;
- m_modificationDate = TQDateTime::tqcurrentDateTime();
+ m_modificationDate = TQDateTime::currentDateTime();
m_firstSave = false;
}
@@ -878,7 +878,7 @@ void KoDocumentInfoAbout::resetMetaData()
{
m_editingCycles = 0;
m_initialCreator = m_docInfo->creator();
- m_creationDate = TQDateTime::tqcurrentDateTime();
+ m_creationDate = TQDateTime::currentDateTime();
m_modificationDate = TQDateTime();
}
diff --git a/lib/kofficecore/KoDocumentInfoDlg.cpp b/lib/kofficecore/KoDocumentInfoDlg.cpp
index 5973dbb4..8fd35ea9 100644
--- a/lib/kofficecore/KoDocumentInfoDlg.cpp
+++ b/lib/kofficecore/KoDocumentInfoDlg.cpp
@@ -191,7 +191,7 @@ void KoDocumentInfoDlg::deleteInfo()
void KoDocumentInfoDlg::resetMetaData()
{
- TQString s = KGlobal::locale()->formatDateTime( TQDateTime::tqcurrentDateTime() );
+ TQString s = KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() );
d->m_aboutWidget->labelCreated->setText( s + ", " + d->m_info->creator() );
d->m_aboutWidget->labelModified->setText( "" );
d->m_aboutWidget->labelRevision->setText( "0" );
diff --git a/lib/kofficecore/KoFilter.cpp b/lib/kofficecore/KoFilter.cpp
index 628d5f17..e4284e57 100644
--- a/lib/kofficecore/KoFilter.cpp
+++ b/lib/kofficecore/KoFilter.cpp
@@ -65,7 +65,7 @@ KoEmbeddingFilter::KoEmbeddingFilter() : KoFilter()
}
int KoEmbeddingFilter::embedPart( const TQCString& from, TQCString& to,
- KoFilter::ConversiontqStatus& status, const TQString& key )
+ KoFilter::ConversionStatus& status, const TQString& key )
{
++( m_partStack.top()->m_lruPartIndex );
diff --git a/lib/kofficecore/KoFilterChain.cpp b/lib/kofficecore/KoFilterChain.cpp
index 471d6098..37ff5d95 100644
--- a/lib/kofficecore/KoFilterChain.cpp
+++ b/lib/kofficecore/KoFilterChain.cpp
@@ -46,7 +46,7 @@ KoFilterChain::ChainLink::ChainLink( KoFilterChain* chain, KoFilterEntry::Ptr fi
{
}
-KoFilter::ConversiontqStatus KoFilterChain::ChainLink::invokeFilter( const ChainLink* const parentChainLink )
+KoFilter::ConversionStatus KoFilterChain::ChainLink::invokeFilter( const ChainLink* const parentChainLink )
{
if ( !m_filterEntry ) {
kdError( 30500 ) << "This filter entry is null. Strange stuff going on." << endl;
@@ -63,7 +63,7 @@ KoFilter::ConversiontqStatus KoFilterChain::ChainLink::invokeFilter( const Chain
if ( parentChainLink )
setupCommunication( parentChainLink->m_filter );
- KoFilter::ConversiontqStatus status = m_filter->convert( m_from, m_to );
+ KoFilter::ConversionStatus status = m_filter->convert( m_from, m_to );
delete m_filter;
m_filter=0;
return status;
@@ -90,8 +90,8 @@ void KoFilterChain::ChainLink::setupCommunication( const KoFilter* const parentF
if ( !parentFilter )
return;
- const TQMetaObject* const parent = parentFilter->tqmetaObject();
- const TQMetaObject* const child = m_filter->tqmetaObject();
+ const TQMetaObject* const parent = parentFilter->metaObject();
+ const TQMetaObject* const child = m_filter->metaObject();
if ( !parent || !child )
return;
@@ -131,9 +131,9 @@ KoFilterChain::~KoFilterChain()
manageIO(); // Called for the 2nd time in a row -> clean up
}
-KoFilter::ConversiontqStatus KoFilterChain::invokeChain()
+KoFilter::ConversionStatus KoFilterChain::invokeChain()
{
- KoFilter::ConversiontqStatus status = KoFilter::OK;
+ KoFilter::ConversionStatus status = KoFilter::OK;
m_state = Beginning;
int count = m_chainLinks.count();
diff --git a/lib/kofficecore/KoFilterChain.h b/lib/kofficecore/KoFilterChain.h
index d926c613..a044eebe 100644
--- a/lib/kofficecore/KoFilterChain.h
+++ b/lib/kofficecore/KoFilterChain.h
@@ -69,7 +69,7 @@ public:
* @return The return status of the conversion. KoFilter::OK
* if everything is alright.
*/
- KoFilter::ConversiontqStatus invokeChain();
+ KoFilter::ConversionStatus invokeChain();
/**
* Tells the @ref KoFilterManager the output file of the
@@ -182,7 +182,7 @@ private:
ChainLink( KoFilterChain* chain, KoFilterEntry::Ptr filterEntry,
const TQCString& from, const TQCString& to );
- KoFilter::ConversiontqStatus invokeFilter( const ChainLink* const parentChainLink );
+ KoFilter::ConversionStatus invokeFilter( const ChainLink* const parentChainLink );
TQCString from() const { return m_from; }
TQCString to() const { return m_to; }
diff --git a/lib/kofficecore/KoFilterManager.cpp b/lib/kofficecore/KoFilterManager.cpp
index 31a1e43e..e7ee131c 100644
--- a/lib/kofficecore/KoFilterManager.cpp
+++ b/lib/kofficecore/KoFilterManager.cpp
@@ -138,7 +138,7 @@ KoFilterManager::~KoFilterManager()
delete d;
}
-TQString KoFilterManager::import( const TQString& url, KoFilter::ConversiontqStatus& status )
+TQString KoFilterManager::import( const TQString& url, KoFilter::ConversionStatus& status )
{
// Find the mime type for the file to be imported.
KURL u;
@@ -231,7 +231,7 @@ TQString KoFilterManager::import( const TQString& url, KoFilter::ConversiontqSta
return TQString();
}
-KoFilter::ConversiontqStatus KoFilterManager::exp0rt( const TQString& url, TQCString& mimeType )
+KoFilter::ConversionStatus KoFilterManager::exp0rt( const TQString& url, TQCString& mimeType )
{
bool userCancelled = false;
@@ -482,7 +482,7 @@ TQStringList KoFilterManager::mimeFilter( const TQCString& mimetype, Direction d
// TODO maybe use the fake vertex trick from the method below, to make the search faster?
TQStringList nativeMimeTypes;
- nativeMimeTypes.append( TQString::tqfromLatin1( mimetype ) );
+ nativeMimeTypes.append( TQString::fromLatin1( mimetype ) );
nativeMimeTypes += extraNativeMimeTypes;
// Add the native mimetypes first so that they are on top.
diff --git a/lib/kofficecore/KoFilterManager.h b/lib/kofficecore/KoFilterManager.h
index 5f0641f4..11158012 100644
--- a/lib/kofficecore/KoFilterManager.h
+++ b/lib/kofficecore/KoFilterManager.h
@@ -81,7 +81,7 @@ public:
* If the TQString which is returned isEmpty() and the status is OK,
* then we imported the file directly into the document.
*/
- TQString import( const TQString& url, KoFilter::ConversiontqStatus& status );
+ TQString import( const TQString& url, KoFilter::ConversionStatus& status );
/**
* @brief Exports the given file/document to the specified URL/mimetype.
*
@@ -89,7 +89,7 @@ public:
* and when the method returns @p mimeType contains this mimetype.
* Oh, well, export is a C++ keyword ;)
*/
- KoFilter::ConversiontqStatus exp0rt( const TQString& url, TQCString& mimeType );
+ KoFilter::ConversionStatus exp0rt( const TQString& url, TQCString& mimeType );
diff --git a/lib/kofficecore/KoGenStyles.cpp b/lib/kofficecore/KoGenStyles.cpp
index 5c8f680f..e140ac50 100644
--- a/lib/kofficecore/KoGenStyles.cpp
+++ b/lib/kofficecore/KoGenStyles.cpp
@@ -225,7 +225,7 @@ void KoGenStyle::writeStyle( KoXmlWriter* writer, KoGenStyles& styles, const cha
}
if ( !m_familyName.isEmpty() )
const_cast<KoGenStyle *>( this )->
- addAttribute( "style:family", TQString::tqfromLatin1( m_familyName ) );
+ addAttribute( "style:family", TQString::fromLatin1( m_familyName ) );
else {
if ( qstrcmp( elementName, "style:style" ) == 0 )
kdWarning(30003) << "User style " << name << " is without family - invalid. m_type=" << m_type << endl;
diff --git a/lib/kofficecore/KoGlobal.cpp b/lib/kofficecore/KoGlobal.cpp
index 8ba1c077..3c979f93 100644
--- a/lib/kofficecore/KoGlobal.cpp
+++ b/lib/kofficecore/KoGlobal.cpp
@@ -136,7 +136,7 @@ void KoGlobal::createListOfLanguages()
// currently have en_GB or en_US etc.
const TQStringList translationList = KGlobal::dirs()->findAllResources("locale",
- TQString::tqfromLatin1("*/entry.desktop"));
+ TQString::fromLatin1("*/entry.desktop"));
for ( TQStringList::ConstIterator it = translationList.begin();
it != translationList.end(); ++it )
{
diff --git a/lib/kofficecore/KoMainWindow.cpp b/lib/kofficecore/KoMainWindow.cpp
index 1219bf09..4428d524 100644
--- a/lib/kofficecore/KoMainWindow.cpp
+++ b/lib/kofficecore/KoMainWindow.cpp
@@ -499,7 +499,7 @@ void KoMainWindow::updateCaption()
// Get caption from document info (title(), in about page)
if ( rootDocument()->documentInfo() )
{
- KoDocumentInfoPage * page = rootDocument()->documentInfo()->page( TQString::tqfromLatin1("about") );
+ KoDocumentInfoPage * page = rootDocument()->documentInfo()->page( TQString::fromLatin1("about") );
if (page)
caption = static_cast<KoDocumentInfoAbout *>(page)->title();
}
@@ -1212,7 +1212,7 @@ void KoMainWindow::print(bool quick) {
if ( title.isEmpty() ) {
// #139905 - breaks message freeze though
//const TQString programName = instance()->aboutData() ? instance()->aboutData()->programName() : instance()->instanceName();
- //title = i18n("%1 unsaved document (%2)").tqarg(programName).tqarg(KGlobal::locale()->formatDate(TQDate::tqcurrentDate(), true/*short*/));
+ //title = i18n("%1 unsaved document (%2)").tqarg(programName).tqarg(KGlobal::locale()->formatDate(TQDate::currentDate(), true/*short*/));
}
printer.setDocName( title );
printer.setDocFileName( fileName );
diff --git a/lib/kofficecore/KoPageLayout.cpp b/lib/kofficecore/KoPageLayout.cpp
index 05eff10b..d01ca6db 100644
--- a/lib/kofficecore/KoPageLayout.cpp
+++ b/lib/kofficecore/KoPageLayout.cpp
@@ -198,15 +198,15 @@ KoFormat KoPageFormat::guessFormat( double width, double height )
TQString KoPageFormat::formatString( KoFormat format )
{
if ( format <= PG_LAST_FORMAT )
- return TQString::tqfromLatin1( pageFormatInfo[ format ].shortName );
- return TQString::tqfromLatin1( "A4" );
+ return TQString::fromLatin1( pageFormatInfo[ format ].shortName );
+ return TQString::fromLatin1( "A4" );
}
KoFormat KoPageFormat::formatFromString( const TQString & string )
{
for ( int i = 0 ; i <= PG_LAST_FORMAT ; ++i )
{
- if (string == TQString::tqfromLatin1( pageFormatInfo[ i ].shortName ))
+ if (string == TQString::fromLatin1( pageFormatInfo[ i ].shortName ))
return pageFormatInfo[ i ].format;
}
// We do not know the format name, so we have a custom format
diff --git a/lib/kofficecore/KoPictureEps.cpp b/lib/kofficecore/KoPictureEps.cpp
index 9edbc981..236b08d7 100644
--- a/lib/kofficecore/KoPictureEps.cpp
+++ b/lib/kofficecore/KoPictureEps.cpp
@@ -399,7 +399,7 @@ bool KoPictureEps::loadData(const TQByteArray& array, const TQString& /* extensi
kdError(30003) << "Not standard bounding box: " << line << endl;
return false;
}
- kdDebug(30003) << "Reg. Exp. Found: " << exp.tqcapturedTexts() << endl;
+ kdDebug(30003) << "Reg. Exp. Found: " << exp.capturedTexts() << endl;
rect.setLeft((int)exp.cap(1).toDouble());
rect.setTop((int)exp.cap(2).toDouble());
rect.setRight((int)exp.cap(3).toDouble());
diff --git a/lib/kofficecore/KoPictureKey.cpp b/lib/kofficecore/KoPictureKey.cpp
index 0badb429..32d73336 100644
--- a/lib/kofficecore/KoPictureKey.cpp
+++ b/lib/kofficecore/KoPictureKey.cpp
@@ -139,7 +139,7 @@ void KoPictureKey::loadAttributes( const TQDomElement &elem )
TQString KoPictureKey::toString() const
{
// We do not use the default TQDateTime::toString has it does not show microseconds
- return TQString::tqfromLatin1( "%1 %2" )
+ return TQString::fromLatin1( "%1 %2" )
.tqarg( m_filename, m_lastModified.toString("yyyy-MM-dd hh:mm:ss.zzz") );
}
diff --git a/lib/kofficecore/KoQueryTrader.cpp b/lib/kofficecore/KoQueryTrader.cpp
index 0003d00d..cc9ab920 100644
--- a/lib/kofficecore/KoQueryTrader.cpp
+++ b/lib/kofficecore/KoQueryTrader.cpp
@@ -76,14 +76,14 @@ KoDocument* KoDocumentEntry::createDoc( KoDocument* parent, const char* name ) c
KoDocumentEntry KoDocumentEntry::queryByMimeType( const TQString & mimetype )
{
- TQString constr = TQString::tqfromLatin1( "[X-KDE-NativeMimeType] == '%1' or '%2' in [X-KDE-ExtraNativeMimeTypes]" ).tqarg( mimetype ).tqarg( mimetype );
+ TQString constr = TQString::fromLatin1( "[X-KDE-NativeMimeType] == '%1' or '%2' in [X-KDE-ExtraNativeMimeTypes]" ).tqarg( mimetype ).tqarg( mimetype );
TQValueList<KoDocumentEntry> vec = query( false,constr );
if ( vec.isEmpty() )
{
kdWarning(30003) << "Got no results with " << constr << endl;
// Fallback to the old way (which was probably wrong, but better be safe)
- TQString constr = TQString::tqfromLatin1( "'%1' in ServiceTypes" ).tqarg( mimetype );
+ TQString constr = TQString::fromLatin1( "'%1' in ServiceTypes" ).tqarg( mimetype );
vec = query( constr );
if ( vec.isEmpty() )
{
diff --git a/lib/kofficecore/KoSpeaker.cpp b/lib/kofficecore/KoSpeaker.cpp
index 75c8fec8..4728c7a8 100644
--- a/lib/kofficecore/KoSpeaker.cpp
+++ b/lib/kofficecore/KoSpeaker.cpp
@@ -136,7 +136,7 @@ void KoSpeaker::probe()
TQPoint pos;
bool spoke = false;
if ( d->m_speakFlags & SpeakFocusWidget ) {
- w = kapp->tqfocusWidget();
+ w = kapp->focusWidget();
if (w) {
spoke = maybeSayWidget(w);
if (!spoke)
diff --git a/lib/kofficecore/KoUnit.cpp b/lib/kofficecore/KoUnit.cpp
index cc882345..3ba89f24 100644
--- a/lib/kofficecore/KoUnit.cpp
+++ b/lib/kofficecore/KoUnit.cpp
@@ -183,15 +183,15 @@ KoUnit::Unit KoUnit::unit( const TQString &_unitName, bool* ok )
{
if ( ok )
*ok = true;
- if ( _unitName == TQString::tqfromLatin1( "mm" ) ) return U_MM;
- if ( _unitName == TQString::tqfromLatin1( "cm" ) ) return U_CM;
- if ( _unitName == TQString::tqfromLatin1( "dm" ) ) return U_DM;
- if ( _unitName == TQString::tqfromLatin1( "in" )
- || _unitName == TQString::tqfromLatin1("inch") /*compat*/ ) return U_INCH;
- if ( _unitName == TQString::tqfromLatin1( "pi" ) ) return U_PI;
- if ( _unitName == TQString::tqfromLatin1( "dd" ) ) return U_DD;
- if ( _unitName == TQString::tqfromLatin1( "cc" ) ) return U_CC;
- if ( _unitName == TQString::tqfromLatin1( "pt" ) ) return U_PT;
+ if ( _unitName == TQString::fromLatin1( "mm" ) ) return U_MM;
+ if ( _unitName == TQString::fromLatin1( "cm" ) ) return U_CM;
+ if ( _unitName == TQString::fromLatin1( "dm" ) ) return U_DM;
+ if ( _unitName == TQString::fromLatin1( "in" )
+ || _unitName == TQString::fromLatin1("inch") /*compat*/ ) return U_INCH;
+ if ( _unitName == TQString::fromLatin1( "pi" ) ) return U_PI;
+ if ( _unitName == TQString::fromLatin1( "dd" ) ) return U_DD;
+ if ( _unitName == TQString::fromLatin1( "cc" ) ) return U_CC;
+ if ( _unitName == TQString::fromLatin1( "pt" ) ) return U_PT;
if ( ok )
*ok = false;
return U_PT;
@@ -199,14 +199,14 @@ KoUnit::Unit KoUnit::unit( const TQString &_unitName, bool* ok )
TQString KoUnit::unitName( Unit _unit )
{
- if ( _unit == U_MM ) return TQString::tqfromLatin1( "mm" );
- if ( _unit == U_CM ) return TQString::tqfromLatin1( "cm" );
- if ( _unit == U_DM ) return TQString::tqfromLatin1( "dm" );
- if ( _unit == U_INCH ) return TQString::tqfromLatin1( "in" );
- if ( _unit == U_PI ) return TQString::tqfromLatin1( "pi" );
- if ( _unit == U_DD ) return TQString::tqfromLatin1( "dd" );
- if ( _unit == U_CC ) return TQString::tqfromLatin1( "cc" );
- return TQString::tqfromLatin1( "pt" );
+ if ( _unit == U_MM ) return TQString::fromLatin1( "mm" );
+ if ( _unit == U_CM ) return TQString::fromLatin1( "cm" );
+ if ( _unit == U_DM ) return TQString::fromLatin1( "dm" );
+ if ( _unit == U_INCH ) return TQString::fromLatin1( "in" );
+ if ( _unit == U_PI ) return TQString::fromLatin1( "pi" );
+ if ( _unit == U_DD ) return TQString::fromLatin1( "dd" );
+ if ( _unit == U_CC ) return TQString::fromLatin1( "cc" );
+ return TQString::fromLatin1( "pt" );
}
void KoUnit::saveOasis(KoXmlWriter* settingsWriter, Unit _unit)
diff --git a/lib/kofficecore/KoView.cpp b/lib/kofficecore/KoView.cpp
index debb9f7c..7dc1f0b0 100644
--- a/lib/kofficecore/KoView.cpp
+++ b/lib/kofficecore/KoView.cpp
@@ -671,12 +671,12 @@ void KoView::endOperation()
KoMainWindow * KoView::shell() const
{
- return dynamic_cast<KoMainWindow *>( tqtopLevelWidget() );
+ return dynamic_cast<KoMainWindow *>( topLevelWidget() );
}
KMainWindow * KoView::mainWindow() const
{
- return dynamic_cast<KMainWindow *>( tqtopLevelWidget() );
+ return dynamic_cast<KMainWindow *>( topLevelWidget() );
}
KStatusBar * KoView::statusBar() const
diff --git a/lib/kofficecore/kkbdaccessextensions.cpp b/lib/kofficecore/kkbdaccessextensions.cpp
index 9535c14a..763bd792 100644
--- a/lib/kofficecore/kkbdaccessextensions.cpp
+++ b/lib/kofficecore/kkbdaccessextensions.cpp
@@ -274,7 +274,7 @@ bool KKbdAccessExtensions::eventFilter( TQObject *o, TQEvent *e )
TQWidgetList* KKbdAccessExtensions::getAllPanels()
{
- TQWidgetList* allWidgets = kapp->tqallWidgets();
+ TQWidgetList* allWidgets = kapp->allWidgets();
TQWidgetList* allPanels = new TQWidgetList;
TQWidget* widget = allWidgets->first();
while (widget) {
@@ -390,7 +390,7 @@ void KKbdAccessExtensions::showIcon()
{
if (!d->panel) return;
TQPoint p;
- // kdDebug() << "KKbdAccessExtensions::showIcon: tqtopLevelWidget = " << d->panel->tqtopLevelWidget()->name() << endl;
+ // kdDebug() << "KKbdAccessExtensions::showIcon: topLevelWidget = " << d->panel->topLevelWidget()->name() << endl;
if (::tqqt_cast<TQSplitter*>( d->panel )) {
TQSplitter* splitter = dynamic_cast<TQSplitter *>(d->panel);
int handleNdx = d->handleNdx - 1;
@@ -413,8 +413,8 @@ void KKbdAccessExtensions::showIcon()
p = dockWindow->pos();
if (dockWindow->area()) {
// kdDebug() << "KKbdAccessExtensions::showIcon: pos = " << p << " of window = " << dockWindow->parentWidget()->name() << endl;
- p = dockWindow->parentWidget()->mapTo(dockWindow->tqtopLevelWidget(), p);
- // kdDebug() << "KKbdAccessExtensions::showIcon: mapTo = " << p << " of window = " << dockWindow->tqtopLevelWidget()->name() << endl;
+ p = dockWindow->parentWidget()->mapTo(dockWindow->topLevelWidget(), p);
+ // kdDebug() << "KKbdAccessExtensions::showIcon: mapTo = " << p << " of window = " << dockWindow->topLevelWidget()->name() << endl;
// TODO: How to get the handle width?
if (d->handleNdx == 1) {
d->icon->setShape(TQt::SizeHorCursor);
@@ -440,7 +440,7 @@ void KKbdAccessExtensions::showIcon()
// else Handle is above the dock window.
}
}
- p = dockWindow->tqtopLevelWidget()->mapToGlobal(p);
+ p = dockWindow->topLevelWidget()->mapToGlobal(p);
} else {
d->icon->setShape(TQt::SizeAllCursor);
p = TQPoint(dockWindow->width() / 2, dockWindow->height() / 2);
@@ -571,7 +571,7 @@ void KKbdAccessExtensions::displayAccessKeys()
}
// Find all visible, focusable widgets and create a TQLabel for each. Don't exceed
// available list of access keys.
- TQWidgetList* allWidgets = kapp->tqallWidgets();
+ TQWidgetList* allWidgets = kapp->allWidgets();
TQWidget* widget = allWidgets->first();
int accessCount = 0;
int maxAccessCount = availableAccessKeys.length();
diff --git a/lib/kofficecore/koDetailsPaneBase.ui b/lib/kofficecore/koDetailsPaneBase.ui
index c29e4a46..2dc1c6f4 100644
--- a/lib/kofficecore/koDetailsPaneBase.ui
+++ b/lib/kofficecore/koDetailsPaneBase.ui
@@ -96,7 +96,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>20</height>
@@ -158,7 +158,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>20</height>
@@ -191,7 +191,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>20</height>
@@ -208,7 +208,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>20</height>
diff --git a/lib/kofficecore/koDocumentInfoAboutWidget.ui b/lib/kofficecore/koDocumentInfoAboutWidget.ui
index cf65eb81..bfd4d49e 100644
--- a/lib/kofficecore/koDocumentInfoAboutWidget.ui
+++ b/lib/kofficecore/koDocumentInfoAboutWidget.ui
@@ -31,7 +31,7 @@
<property name="name">
<cstring>pixmapLabel</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>56</width>
<height>56</height>
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>31</height>
@@ -189,7 +189,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>90</width>
<height>70</height>
@@ -206,7 +206,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -277,13 +277,13 @@
<property name="name">
<cstring>pbReset</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>24</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>24</height>
@@ -321,7 +321,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>50</width>
<height>16</height>
diff --git a/lib/kofficecore/koDocumentInfoAuthorWidget.ui b/lib/kofficecore/koDocumentInfoAuthorWidget.ui
index 60353b91..e007e1a2 100644
--- a/lib/kofficecore/koDocumentInfoAuthorWidget.ui
+++ b/lib/kofficecore/koDocumentInfoAuthorWidget.ui
@@ -31,7 +31,7 @@
<property name="name">
<cstring>labelAuthor</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>56</width>
<height>56</height>
@@ -264,7 +264,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/lib/kofficecore/koDocumentInfoUserMetadataWidget.ui b/lib/kofficecore/koDocumentInfoUserMetadataWidget.ui
index 2a8a531e..d97a33f2 100644
--- a/lib/kofficecore/koDocumentInfoUserMetadataWidget.ui
+++ b/lib/kofficecore/koDocumentInfoUserMetadataWidget.ui
@@ -36,7 +36,7 @@
<property name="name">
<cstring>kPushButton2</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>130</width>
<height>0</height>
@@ -64,7 +64,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>101</height>
diff --git a/lib/kofficecore/KoFilter.h b/lib/kofficecore/KoFilter.h
index 77439648..dc8c2947 100644
--- a/lib/kofficecore/KoFilter.h
+++ b/lib/kofficecore/KoFilter.h
@@ -61,7 +61,7 @@ public:
* Feel free to add some more error conditions @em before the last item
* if it's needed.
*/
- enum ConversiontqStatus { OK, StupidError, UsageError, CreationError, FileNotFound,
+ enum ConversionStatus { OK, StupidError, UsageError, CreationError, FileNotFound,
StorageCreationError, BadMimeType, BadConversionGraph,
EmbeddedDocError, WrongFormat, NotImplemented,
ParsingError, InternalError, UnexpectedEOF,
@@ -79,10 +79,10 @@ public:
*
* @param from The mimetype of the source file/document
* @param to The mimetype of the destination file/document
* @return The error status, see the @ref #ConversiontqStatus enum.
* KoFilter::OK means that everything is alright.
*/
- virtual ConversiontqStatus convert( const TQCString& from, const TQCString& to ) = 0;
+ virtual ConversionStatus convert( const TQCString& from, const TQCString& to ) = 0;
signals:
/**
@@ -201,7 +201,7 @@ protected:
* within the embedding filter).
*/
int embedPart( const TQCString& from, TQCString& to,
- KoFilter::ConversiontqStatus& status,
+ KoFilter::ConversionStatus& status,
const TQString& key = TQString() );
/**
@@ -79,10 +79,10 @@ public:
* @param from The mimetype of the source file/document
* @param to The mimetype of the destination file/document
- * @return The error status, see the @ref #ConversiontqStatus enum.
+ * @return The error status, see the @ref #ConversionStatus enum.
* KoFilter::OK means that everything is alright.
*/